State

Struct State 

pub struct State { /* private fields */ }
The internal state of an Editor.

Implementations

Source

impl State

pub fn new() -> Self

Creates a new State.

pub fn update<Message>( &mut self, editor: &impl Editor, event: &Event, bounds: Rectangle, padding: Padding, cursor: Cursor, key_binding: impl Fn(KeyPress) -> Option<Binding<Message>>, ) -> Option<Update<Message>>

Updates the State for the given Editor and returns any relevant Update.

pub fn input_method<'a>( &'a self, editor: &impl Editor, position: Point, ) -> InputMethod<&'a str>

Returns the current InputMethod of the State for the given Editor.

pub fn draw<Renderer: Renderer>( &self, editor: &Renderer::Editor, renderer: &mut Renderer, position: Point, clip_bounds: Rectangle, style: Style, )

Draws the given Editor with the current State.

pub fn is_cursor_visible(&self) -> bool

Returns whether the cursor of the Editor is visible.

Source

impl State

pub fn is_focused(&self) -> bool

Returns whether the Editor is currently focused or not.