pub enum Update<Message> {
Action(Action),
Focus,
Unfocus,
InputMethod,
Release,
Copy(String),
Paste,
RedrawAt(Instant),
Custom(Message),
Sequence(Vec<Update<Message>>),
}Expand description
The update of an Editor, returned by State::update.
Variants
Action(Action)
Focus
The Editor just gained focus.
Unfocus
The Editor just lost focus.
InputMethod
The Editor changed its InputMethod.
Release
A mouse press was released in the Editor.
Copy(String)
The Editor must copy some text to the clipboard.
Paste
The Editor must paste the clipboard contents.
RedrawAt(Instant)
Custom(Message)
The Editor produced a custom message that must be published.
Sequence(Vec<Update<Message>>)
The Editor produced a sequence of updates.